@@ -1,7 +1,7 @@
 package Finance::Currency::FiatX;
 
 our $DATE = '2018-06-19'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -12,6 +12,11 @@ use List::Util qw(max);
 
 our %SPEC;
 
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'Fiat currency exchange rate library',
+};
+
 our %args_db = (
     dbh => {
         schema => ['obj*'],
@@ -635,7 +640,7 @@ sub _get_all_spot_rates_or_get_spot_rate {
 }
 
 1;
-# ABSTRACT: Get spot (latest) rate
+# ABSTRACT: Fiat currency exchange rate library
 
 __END__
 
@@ -645,11 +650,11 @@ __END__
 
 =head1 NAME
 
-Finance::Currency::FiatX - Get spot (latest) rate
+Finance::Currency::FiatX - Fiat currency exchange rate library
 
 =head1 VERSION
 
-This document describes version 0.004 of Finance::Currency::FiatX (from Perl distribution Finance-Currency-FiatX), released on 2018-06-19.
+This document describes version 0.005 of Finance::Currency::FiatX (from Perl distribution Finance-Currency-FiatX), released on 2018-06-19.
 
 =head1 SYNOPSIS
 
@@ -658,8 +663,9 @@ See L<fiatx> from L<App::fiatx> for an example on how to use this module.
 =head1 DESCRIPTION
 
 FiatX is a library/application to convert one fiat currency to another using
-several backend modules (C<Finance::Currency::Convert::*>) and store the rates
-in L<DBI> database.
+several backend modules ("sources", C<Finance::Currency::FiatX::Source::*>,
+which in turns usually utilize C<Finance::Currency::Convert::*>) and store the
+rates in L<DBI> database for caching.
 
 =head1 FUNCTIONS
 
